==> haskell-abstract-deque-0.3-191-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-abstract-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 abstract-deque
version:              0.3
visibility:           public
id:                   abstract-deque-0.3-A0SZ3XfolkU5YwC5s8SEYK
key:                  abstract-deque-0.3-A0SZ3XfolkU5YwC5s8SEYK
license:              BSD-3-Clause
maintainer:           rrnewton@gmail.com
author:               Ryan R. Newton
homepage:             https://github.com/rrnewton/haskell-lockfree/wiki
synopsis:             Abstract, parameterized interface to mutable Deques.
description:
    An abstract interface to highly-parameterizable queues/deques.

    Background: There exists a feature space for queues that extends between:

    * simple, single-ended, non-concurrent, bounded queues

    * double-ended, threadsafe, growable queues

    ... with important points inbetween (such as
    the queues used for work-stealing).

    This package includes an interface for Deques that allows the
    programmer to use a single API for all of the above, while using the
    type-system to select an efficient implementation given the
    requirements (using type families).

    This package also includes a simple reference implementation based
    on '\''IORef'\'' and "Data.Sequence".

category:             Data 
abi:                  4ffe5a7f2eb443a96c2378789fbd5b87
exposed:              True
exposed-modules:
    Data.Concurrent.Deque.Class Data.Concurrent.Deque.Debugger
    Data.Concurrent.Deque.Reference
    Data.Concurrent.Deque.Reference.DequeInstance

import-dirs:          /usr/lib/ghc-9.0.2/site-local/abstract-deque-0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/abstract-deque-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-abstract-deque
hs-libraries:         HSabstract-deque-0.3-A0SZ3XfolkU5YwC5s8SEYK
depends:
    array-0.5.4.0 base-4.15.1.0 containers-0.6.4.1
    random-1.2.1.1-Jsd8w3Sbg0mK17rOHVUzgD time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-abstract-deque/html/abstract-deque.haddock

haddock-html:         /usr/share/doc/haskell-abstract-deque/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-abstract-deque-0.3-199-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-abstract-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 abstract-deque
version:              0.3
visibility:           public
id:                   abstract-deque-0.3-HgjvK8hbUvb5Nm65k8NdvI
key:                  abstract-deque-0.3-HgjvK8hbUvb5Nm65k8NdvI
license:              BSD-3-Clause
maintainer:           rrnewton@gmail.com
author:               Ryan R. Newton
homepage:             https://github.com/rrnewton/haskell-lockfree/wiki
synopsis:             Abstract, parameterized interface to mutable Deques.
description:
    An abstract interface to highly-parameterizable queues/deques.

    Background: There exists a feature space for queues that extends between:

    * simple, single-ended, non-concurrent, bounded queues

    * double-ended, threadsafe, growable queues

    ... with important points inbetween (such as
    the queues used for work-stealing).

    This package includes an interface for Deques that allows the
    programmer to use a single API for all of the above, while using the
    type-system to select an efficient implementation given the
    requirements (using type families).

    This package also includes a simple reference implementation based
    on '\''IORef'\'' and "Data.Sequence".

category:             Data 
abi:                  0f266c3e9b9767ce67e2ecb7b9e9d3d6
exposed:              True
exposed-modules:
    Data.Concurrent.Deque.Class Data.Concurrent.Deque.Debugger
    Data.Concurrent.Deque.Reference
    Data.Concurrent.Deque.Reference.DequeInstance

import-dirs:          /usr/lib/ghc-9.0.2/site-local/abstract-deque-0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/abstract-deque-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-abstract-deque
hs-libraries:         HSabstract-deque-0.3-HgjvK8hbUvb5Nm65k8NdvI
depends:
    array-0.5.4.0 base-4.15.1.0 containers-0.6.4.1
    random-1.2.1.1-C6YbKOqj1b9FtHcTQfM70Q time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-abstract-deque/html/abstract-deque.haddock

haddock-html:         /usr/share/doc/haskell-abstract-deque/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
